@@ -1,3 +1,17 @@
+# Copyright (C) 2018-2021 Arnaud Belcour - Inria Dyliss
+# This program is free software: you can redistribute it and/or modify
+# it under the terms of the GNU Lesser General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+# GNU Lesser General Public License for more details.
+
+# You should have received a copy of the GNU Lesser General Public License
+# along with this program. If not, see <http://www.gnu.org/licenses/>
+
 """
 Check results from Pathway Tools command:
 -check_pwt: results from PathoLogic (by looking at pathologic.log)
@@ -75,6 +89,8 @@ def check_pwt(multiprocess_run_pwts, patho_log_folder):
                             if patho_log_folder:
                                 patho_error_file.write(line)
 
+                    # Search for Build done line and its following line which look like (for Pathway Tools 25.0):
+                    # PGDB contains XXXX genes, XXXX polypeptides, XXXX base pathways, XXXX reactions, XXXX compounds
                     if 'Build done.' in line or 'PGDB build done.' in line:
                         pgdb_build_done = True
                         if patho_log_folder:
@@ -88,8 +104,14 @@ def check_pwt(multiprocess_run_pwts, patho_log_folder):
                                 warning_line = 'Number of warning: ' + str(warning_count) + '. More information in ' + patho_log + '.\n'
                                 patho_error_file.write(warning_line)
                             gene_number = int(resume_inference_line.split('PGDB contains ')[1].split(' genes')[0])
-                            protein_number = int(resume_inference_line.split('genes, ')[1].split(' proteins')[0])
-                            pathway_number = int(resume_inference_line.split('proteins, ')[1].split(' base pathways')[0])
+                            # proteins is listed in pathologic.log for Pathway Tools inferior to 25.0
+                            # Since the 25.0 polypeptides replace proteins
+                            if 'proteins' in resume_inference_line:
+                                protein_number = int(resume_inference_line.split('genes, ')[1].split(' proteins')[0])
+                                pathway_number = int(resume_inference_line.split('proteins, ')[1].split(' base pathways')[0])
+                            elif 'polypeptides' in resume_inference_line:
+                                protein_number = int(resume_inference_line.split('genes, ')[1].split(' polypeptides')[0])
+                                pathway_number = int(resume_inference_line.split('polypeptides, ')[1].split(' base pathways')[0])
                             reaction_number = int(resume_inference_line.split('base pathways, ')[1].split(' reactions')[0])
                             compound_number = int(resume_inference_line.split('reactions, ')[1].split(' compounds')[0])
 
